@@ -6,14 +6,16 @@ class utility:
     def __init__(self):
         print("constructor created")
 
-    
-    def list_users(self,aws_secret_access_key,aws_access_key_id,aws_session_token,region_name,day):
+    def boto_session(self,aws_secret_access_key,aws_access_key_id,aws_session_token,region_name):
         session = boto3.session.Session(
         aws_access_key_id=aws_secret_access_key,
         aws_secret_access_key=aws_access_key_id,
         aws_session_token=aws_session_token,
         region_name=region_name
         )
+        print("Boto3 Session Started")
+
+    def list_users(self,day):
         iam = session.client(
         service_name='iam'
         )
